@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1102';
 
 use Moo;
 use strictures 2;
@@ -242,7 +242,7 @@ sub draw {
             );
         }
         else {
-            my $temp = $self->fretboard->{$string}[ ($self->position + $note - 1) % @{ $self->fretboard->{1} } ];
+            my $temp = $self->_note_at($string, $note);
             push @chord, $temp;
 
             print "Dot at $note,$string = $temp\n" if $self->verbose;
@@ -390,7 +390,7 @@ sub _draw_horiz {
             );
         }
         else {
-            my $temp = $self->fretboard->{$string}[ ($self->position + $note - 1) % @{ $self->fretboard->{1} } ];
+            my $temp = $self->_note_at($string, $note);
             unshift @chord, $temp;
 
             print "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
@@ -454,6 +454,11 @@ sub _fret_match {
         ( $self->position + $fret == 24 );
 }
 
+sub _note_at {
+    my ($self, $string, $n) = @_;
+    return $self->fretboard->{$string}[ ($self->position + $n - 1) % @{ $self->fretboard->{1} } ];
+}
+
 sub _output_image {
     my ($self, $img) = @_;
     my $name = $self->outfile . '.' . $self->type;
@@ -480,7 +485,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1101
+version 0.1102
 
 =head1 SYNOPSIS
 
